package confutil;

import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

/**
 * This class represents a simple message box. Such a message box contains a text message
 * and an OK button or a Cancel button or both.
 *
 * <p>Title: P2PWNC configuration utility</p>
 * <p>Description: Linksys WRT54GS P2PWNC configuration utility</p>
 * <p>Copyright: Copyright (c) 2005</p>
 * <p>Company: </p>
 * @author pfrag
 * @version 1.0
 */
public class MessageBox extends JDialog implements ActionListener {
  /**
   * "OK" button only.
   */
  public final static int MB_OK = 1;
  /**
   * "Cancel" button only.
   */
  public final static int MB_OK_CANCEL = 2;
  /**
   * "OK" and "Cancel" buttons.
   */
  public final static int MB_CANCEL = 3;

  /**
   * The return value of the MessageBox. It can be MessageBox.MB_OK or MessageBox.MB_CANCEL.
   */
  public int retval;

  JPanel panel1 = new JPanel();
  GridBagLayout gridBagLayout1 = new GridBagLayout();
  JLabel lblMsg = new JLabel();

  JLabel lbl1 = new JLabel();
  JLabel lbl2 = new JLabel();
  JLabel lbl3 = new JLabel();

  GridBagLayout gridBagLayout2 = new GridBagLayout();
  JButton btOk = new JButton();
  JButton btCancel = new JButton();
  int mode;

  /**
   * Constructs a MessageBox object titled "title", showing the "message" message.
   * @param frame Frame
   * Parent frame.
   * @param title String
   * Message box title.
   * @param modal boolean
   * True if the message box is modal.
   * @param message String
   * The message to be shown.
   * @param m int
   * Indicates what buttons will be present on the message box. Legal values are MessageBox.MB_OK,
   * MessageBox.MB_CANCEL and MessageBox.MB_OK_CANCEL.
   */
  public MessageBox(Frame frame, String title, boolean modal, String message,
                       int m) {
    super(frame, title, modal);
    try {
      jbInit(message, m);
      pack();
    }
    catch (Exception ex) {
      ex.printStackTrace();
    }
  }

  /**
   * Constructs a message box without a title and message, non-modal and with an "OK" button.
   */
  public MessageBox() {
    this(null, "", false, "", MB_OK);
  }

  private void jbInit(String message, int m) throws Exception {
    panel1.setLayout(gridBagLayout2);
    this.getContentPane().setLayout(gridBagLayout1);
    lblMsg.setRequestFocusEnabled(true);
    lblMsg.setText("<html><b><center>" + message + "</center></b></html>");
    btOk.setText("OK");
    btCancel.setActionCommand("Cancel");
    btCancel.setText("Cancel");
    mode = m;
    getContentPane().add(panel1, new GridBagConstraints(0, 0, 1, 1, 1.0, 1.0
        , GridBagConstraints.CENTER, GridBagConstraints.BOTH,
        new Insets(0, 0, 0, 0), 100, 40));
    panel1.add(lblMsg, new GridBagConstraints(0, 0, 5, 1, 1.0, 0.0
                                              , GridBagConstraints.CENTER,
                                              GridBagConstraints.NONE,
                                              new Insets(0, 0, 0, 0), 0, 0));

    panel1.add(lbl1, new GridBagConstraints(0, 1, 1, 1, 0.2, 0.0
                                              , GridBagConstraints.CENTER,
                                              GridBagConstraints.NONE,
                                              new Insets(0, 0, 0, 0), 0, 0));

    panel1.add(btOk, new GridBagConstraints(1, 1, 1, 1, 0.2, 0.0
                                            , GridBagConstraints.CENTER,
                                            GridBagConstraints.HORIZONTAL,
                                            new Insets(10, 10, 10, 10), 0, 0));
    panel1.add(lbl2, new GridBagConstraints(2, 1, 1, 1, 0.0, 0.0
                                              , GridBagConstraints.CENTER,
                                              GridBagConstraints.NONE,
                                              new Insets(0, 0, 0, 0), 0, 0));

    panel1.add(btCancel, new GridBagConstraints(3, 1, 1, 1, 0.2, 0.0
                                                , GridBagConstraints.CENTER,
                                                GridBagConstraints.HORIZONTAL,
                                                new Insets(10, 10, 10, 10), 0, 0));

    panel1.add(lbl3, new GridBagConstraints(4, 1, 1, 1, 0.2, 0.0
                                              , GridBagConstraints.CENTER,
                                              GridBagConstraints.NONE,
                                              new Insets(0, 0, 0, 0), 0, 0));

    if (mode == MB_OK) {
      btCancel.setVisible(false);
    }

    btOk.addActionListener(this);
    btCancel.addActionListener(this);

    this.setLocation(350, 350);
  }

  public void actionPerformed(ActionEvent e) {
    if (e.getActionCommand().compareToIgnoreCase("ok") == 0) {
      retval = MB_OK;
      this.hide();
      return;
    }
    if (e.getActionCommand().compareToIgnoreCase("cancel") == 0) {
      retval = MB_CANCEL;
      this.hide();
      return;
    }
  }

}
